<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:value-of select="pjm5MeetingRequestGet/MeetingRequest/FileAs" />
        </TITLE>
        <xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
      </HEAD>
      <BODY >
        <xsl:value-of select="adf:GetHeader(pjm5MeetingRequestGet/MeetingRequest)"  disable-output-escaping="yes"/>
        <xsl:apply-templates select="pjm5MeetingRequestGet/MeetingRequest"/>
        <xsl:value-of select="adf:GetFooter(pjm5MeetingRequestGet/MeetingRequest)"  disable-output-escaping="yes"/>
      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="Attendee">
    <xsl:value-of select="adf:GetListMember(EmployeeID, 'Employee', 'Name')"/>
  </xsl:template>

  <xsl:template match="MeetingResource">
    <xsl:value-of select="adf:GetListMember(ResourceID, 'Resource', 'Name')"/>
  </xsl:template>

  <xsl:template match="MeetingRequest">
    <table class="main" cellspacing="0" cellpadding="0" border="0">
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Проект:
              </xsl:when>
              <xsl:otherwise>
                Project:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="ProjectID">
              <xsl:value-of select="adf:GetListMember(ProjectID, 'Project', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>
              
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Организатор:
              </xsl:when>
              <xsl:otherwise>
                Originator:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:value-of select="adf:GetListMember(OriginatorEmployeeID, 'Employee', 'Name')"/>
        </td>
      </tr>
      <xsl:choose>
        <xsl:when test="../Attendee[Required='true']">
          <tr>
            <td>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Обязательные:
                  </xsl:when>
                  <xsl:otherwise>
                    Required:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:for-each select="../Attendee[Required='true']">
                <xsl:apply-templates select="."/>
                <xsl:if test="position()!=last()">, </xsl:if>
              </xsl:for-each>
            </td>
          </tr>
        </xsl:when>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="../Attendee[Required='false']">
          <tr>
            <td>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Необязательные:
                  </xsl:when>
                  <xsl:otherwise>
                    Optional:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:for-each select="../Attendee[Required='false']">
                <xsl:apply-templates select="."/>
                <xsl:if test="position()!=last()">, </xsl:if>
              </xsl:for-each>
            </td>
          </tr>
        </xsl:when>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="../MeetingResource">
          <tr>
            <td>
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Ресурсы:
                  </xsl:when>
                  <xsl:otherwise>
                    Resources:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:for-each select="../MeetingResource">
                <xsl:apply-templates select="."/>
                <xsl:if test="position()!=last()">, </xsl:if>
              </xsl:for-each>
            </td>
          </tr>
        </xsl:when>
      </xsl:choose>
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Вид деятельности:
              </xsl:when>
              <xsl:otherwise>
                Activity Type:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="ActivityTypeID">
              <xsl:value-of select="adf:GetListMember(ActivityTypeID, 'ActivityType', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Место:
              </xsl:when>
              <xsl:otherwise>
                Location:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:value-of select="Location"/>
        </td>
      </tr>
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Начало:
              </xsl:when>
              <xsl:otherwise>
                Start Date:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:value-of select="adf:FormatXmlDate(StartTime,'d')"/>
          <xsl:text > </xsl:text>
          <xsl:value-of select="adf:FormatXmlDate(StartTime,'t')"/>
        </td>
      </tr>
      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Длительность:
              </xsl:when>
              <xsl:otherwise>
                Duration:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:value-of select="Duration"/>
          <xsl:choose>
            <xsl:when test="$lang = 'ru'">
              мин.
            </xsl:when>
            <xsl:otherwise>
              min.
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>

      <tr>
        <td>
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Приоритет:
              </xsl:when>
              <xsl:otherwise>
                Priority:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:value-of select="adf:GetListMember(PriorityID, 'Priority', 'Name')"/>
        </td>
      </tr>
    </table>
  </xsl:template>
</xsl:stylesheet>